==============================================
``qc-utils``: Utility for ENCODE pipeline QC
==============================================

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black
    :alt: Code Style: Black

.. image:: https://img.shields.io/badge/License-MIT-blue.svg
   :target: https://lbesson.mit-license.org/
   :alt: License: MIT

.. image:: https://circleci.com/gh/ENCODE-DCC/qc-utils.svg?style=svg
    :target: https://circleci.com/gh/ENCODE-DCC/qc-utils
    :alt: CircleCI status

.. short-intro-begin

``qc-utils`` is a python package that provides ``QCMetric`` and ``QCMetricRecord`` classes that can be used for representing ENCODE pipeline quality control metrics.

.. short-intro-end

Installation
==============

.. code-block:: console

    $ pip install qc-utils


Project Information
====================

``qc-utils`` is released under the `MIT <https://choosealicense.com/licenses/mit/>`_ license, documentation lives in `readthedocs <https://qc-utils.readthedocs.io/en/latest/>`_, code is hosted on `github <https://github.com/ENCODE-DCC/qc-utils>`_ and the releases on `PyPI <https://pypi.org/project/qc-utils/>`_.
